@@ -41,7 +41,6 @@ def update_config_file(new_config):
     # Read file
     with open(settings.PATH_TO_MS_CONFIG) as json_file:
         data = json.load(json_file)
-        print(data)
 
     # Prepare config to insert
     unique_integration = f"{new_config['monitoring_system']}_{new_config['integration_name']}"
@@ -51,7 +50,7 @@ def update_config_file(new_config):
         data[unique_integration] = new_config
 
     # Update file
-    with open(settings.PATH_TO_MS_CONFIG, 'w+') as outfile:
+    with open(settings.PATH_TO_MS_CONFIG, 'w') as outfile:
         json.dump(data, outfile)
 
 
